{"": "", "Username": "K\u00e4ytt\u00e4j\u00e4tunnus", "Authenticate": "Tunnistaudu", "OK": "OK", "Authorization failed": "Todennus ep\u00e4onnistui", "Write configuration file": "", "Log out": "Kirjaudu ulos", "A bootstrap error has occured": "", "Read configuration file": "", "System": "J\u00e4rjestelm\u00e4", "Please see browser console": "", "General": "", "Elevate": "", "Software": "Ohjelmisto", "Other": "", "Log in": "Kirjaudu sis\u00e4\u00e4n", "Enter": "", "Password": "Salasana", "Tools": "Ty\u00f6kalut", "Quick search": "Pikahaku"}