{"": "", "Username": "Nama pengguna", "Authenticate": "Otentikasi", "OK": "Baik", "Authorization failed": "Otorisasi gagal", "Write configuration file": "Tulis file konfigurasi", "Log out": "Keluar", "A bootstrap error has occured": "Terjadi kesalahan bootstrap", "Read configuration file": "File konfigurasi", "System": "Sistem", "Please see browser console": "Silakan lihat konsol browser", "General": "Umum", "Elevate": "Mengangkat", "Software": "Perangkat lunak", "Other": "Lain", "Log in": "Masuk", "Enter": "Memasukkan", "Password": "Kata sandi", "Tools": "Alat", "Quick search": "Pencarian Cepat"}