{"": "", "Username": "Korisni\u010dko ime", "Authenticate": "Autorizacija", "OK": "U redu", "Authorization failed": "Autorizacija neuspje\u0161na", "Write configuration file": "Izmjeni konfiguracioni fajl", "Log out": "Odjava", "A bootstrap error has occured": "Otkrivena gre\u0161ka sa bootstrapom", "Read configuration file": "Pro\u010ditaj konfiguracioni fajl", "System": "Sistem", "Please see browser console": "Molimo pogledajte konzolu u browseru", "General": "Op\u0161te", "Elevate": "Podigni", "Software": "Softver", "Other": "Ostalo", "Log in": "Uloguj se", "Enter": "Ulazak", "Password": "Lozinka", "Tools": "Alati", "Quick search": "Brza pretraga"}