{"": "", "Username": "Pou\u017e\u00edvate\u013eske meno", "Authenticate": "Overi\u0165", "OK": "OK", "Authorization failed": "Autoriz\u00e1cia zlyhala", "Write configuration file": "", "Log out": "Odhl\u00e1si\u0165 sa", "A bootstrap error has occured": "Vyskytla sa chyba s bootstrap", "Read configuration file": "", "System": "Syst\u00e9m", "Please see browser console": "", "General": "", "Elevate": "", "Software": "Softv\u00e9r", "Other": "In\u00e9", "Log in": "Prihl\u00e1si\u0165 sa", "Enter": "", "Password": "Heslo", "Tools": "N\u00e1stroje", "Quick search": "R\u00fdchle h\u013eadanie"}