{"": "", "Username": "\u7528\u6236\u540d", "Authenticate": "\u8a8d\u8b49", "OK": "OK", "Authorization failed": "\u9a57\u8b49\u5931\u6557", "Write configuration file": "\u5beb\u5165\u8a2d\u5b9a\u6a94", "Log out": "\u767b\u51fa", "A bootstrap error has occured": "", "Read configuration file": "\u8b80\u53d6\u8a2d\u5b9a\u6a94", "System": "\u7cfb\u7d71", "Please see browser console": "", "General": "\u5e38\u9805", "Elevate": "", "Software": "\u8edf\u9ad4", "Other": "\u5176\u4ed6", "Log in": "\u767b\u5165", "Enter": "\u8f38\u5165", "Password": "\u5bc6\u78bc", "Tools": "\u5de5\u5177", "Quick search": "\u5feb\u901f\u641c\u7d22"}